@@ -5,7 +5,7 @@ use Encode qw(decode);
 use base 'Exporter';
 our @EXPORT = qw(convert_to_ascii);
 our @EXPORT_OK = qw(convert_to_ascii);
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 my %char_map;
 
 =encoding utf8
@@ -877,34 +877,51 @@ __DATA__
 050D 47
 050F 54
 0511 45
+051A 51
 051B 71
 051C 57
 051D 77
 051E 4B
 051F 4B
+0526 68
 0527 68
+0528 48
 0529 48
 0531 55
 0536 32
+053C 4C
+053E 4F
+0544 55
 0545 33
 054D 55
 054F 53
 0555 4F
 055A 27
+055B 27
+055C 27
 055D 27
 0561 77
 0563 71
 0566 71
+0567 74
+056A 64
+056B 68
+056C 6C
 0570 68
+0572 6E
+0573 36
 0575 6A
 0578 6E
 057C 6E
 057D 75
+0580 6E
 0581 67
+0582 4C
 0584 70
 0585 6F
 0587 75
 0589 3A
+058A 2E
 05C3 3A
 05D0 4E
 05D5 69
